@@ -1,14 +1,14 @@
 """
 Type annotations for cloud9 service literal definitions.
 
-[Open documentation](./literals.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/literals.html)
 
 Usage::
 
     ```python
-    from mypy_boto3_cloud9.literals import ConnectionType
+    from mypy_boto3_cloud9.literals import ConnectionTypeType
 
-    data: ConnectionType = "CONNECT_SSH"
+    data: ConnectionTypeType = "CONNECT_SSH"
     ```
 """
 import sys
@@ -20,29 +20,29 @@ else:
 
 
 __all__ = (
-    "ConnectionType",
+    "ConnectionTypeType",
     "DescribeEnvironmentMembershipsPaginatorName",
-    "EnvironmentLifecycleStatus",
-    "EnvironmentStatus",
-    "EnvironmentType",
+    "EnvironmentLifecycleStatusType",
+    "EnvironmentStatusType",
+    "EnvironmentTypeType",
     "ListEnvironmentsPaginatorName",
-    "ManagedCredentialsStatus",
-    "MemberPermissions",
-    "Permissions",
+    "ManagedCredentialsStatusType",
+    "MemberPermissionsType",
+    "PermissionsType",
 )
 
 
-ConnectionType = Literal["CONNECT_SSH", "CONNECT_SSM"]
+ConnectionTypeType = Literal["CONNECT_SSH", "CONNECT_SSM"]
 DescribeEnvironmentMembershipsPaginatorName = Literal["describe_environment_memberships"]
-EnvironmentLifecycleStatus = Literal[
+EnvironmentLifecycleStatusType = Literal[
     "CREATED", "CREATE_FAILED", "CREATING", "DELETE_FAILED", "DELETING"
 ]
-EnvironmentStatus = Literal[
+EnvironmentStatusType = Literal[
     "connecting", "creating", "deleting", "error", "ready", "stopped", "stopping"
 ]
-EnvironmentType = Literal["ec2", "ssh"]
+EnvironmentTypeType = Literal["ec2", "ssh"]
 ListEnvironmentsPaginatorName = Literal["list_environments"]
-ManagedCredentialsStatus = Literal[
+ManagedCredentialsStatusType = Literal[
     "DISABLED_BY_COLLABORATOR",
     "DISABLED_BY_DEFAULT",
     "DISABLED_BY_OWNER",
@@ -55,5 +55,5 @@ ManagedCredentialsStatus = Literal[
     "PENDING_START_REMOVAL_BY_COLLABORATOR",
     "PENDING_START_REMOVAL_BY_OWNER",
 ]
-MemberPermissions = Literal["read-only", "read-write"]
-Permissions = Literal["owner", "read-only", "read-write"]
+MemberPermissionsType = Literal["read-only", "read-write"]
+PermissionsType = Literal["owner", "read-only", "read-write"]
